@@ -1,8 +1,9 @@
 import platform
 import re
 from base64 import b64encode
+from typing import Optional, Sequence
 
-from request_header import RequestHeader
+from .request_header import RequestHeader
 
 from worldline.connect.sdk.domain.data_object import DataObject
 from worldline.connect.sdk.domain.shopping_cart_extension import ShoppingCartExtension
@@ -21,11 +22,11 @@ class MetadataProvider(object):
     """
     Provides meta info about the server.
     """
-    __sdk_version = "4.4.0"
+    __sdk_version = "4.3.0"
     __server_meta_info_header = "X-GCS-ServerMetaInfo"
     __prohibited_headers = tuple(sorted([__server_meta_info_header, "X-GCS-Idempotence-Key", "Date", "Content-Type", "Authorization"],
                                         key=str.lower))
-    __metadata_headers = None
+    __metadata_headers: Sequence[RequestHeader] = None
 
     class ServerMetaInfo(DataObject):
         platform_identifier = None
@@ -34,7 +35,7 @@ class MetadataProvider(object):
         integrator = None
         shopping_cart_extension = None
 
-        def to_dictionary(self):
+        def to_dictionary(self) -> dict:
             dictionary = super(MetadataProvider.ServerMetaInfo, self).to_dictionary()
             if self.platform_identifier is not None:
                 dictionary['platformIdentifier'] = self.platform_identifier
@@ -48,7 +49,7 @@ class MetadataProvider(object):
                 dictionary['shoppingCartExtension'] = self.shopping_cart_extension.to_dictionary()
             return dictionary
 
-        def from_dictionary(self, dictionary):
+        def from_dictionary(self, dictionary: dict) -> 'MetadataProvider.ServerMetaInfo':
             super(MetadataProvider.ServerMetaInfo, self).from_dictionary(dictionary)
             if 'platformIdentifier' in dictionary:
                 self.platform_identifier = dictionary['platformIdentifier']
@@ -64,8 +65,8 @@ class MetadataProvider(object):
                 self.shopping_cart_extension = ShoppingCartExtension.create_from_dictionary(dictionary['shoppingCartExtension'])
             return self
 
-    def __init__(self, integrator, shopping_cart_extension=None,
-                 additional_request_headers=()):
+    def __init__(self, integrator: Optional[str], shopping_cart_extension: Optional[ShoppingCartExtension] = None,
+                 additional_request_headers: Optional[Sequence[RequestHeader]] = ()):
         if integrator is None or not integrator.strip():
             raise ValueError("integrator is required")
 
@@ -83,7 +84,7 @@ class MetadataProvider(object):
         server_meta_info.shopping_cart_extension = shopping_cart_extension
 
         server_meta_info_string = DefaultMarshaller.instance().marshal(server_meta_info)
-        server_meta_info_header = RequestHeader(self.__server_meta_info_header, b64encode(server_meta_info_string.encode('utf-8')))
+        server_meta_info_header = RequestHeader(self.__server_meta_info_header, b64encode(server_meta_info_string.encode('utf-8')).decode('utf-8'))
         if not additional_request_headers:
             self.__metadata_headers = tuple([server_meta_info_header])
         else:
@@ -92,13 +93,13 @@ class MetadataProvider(object):
             self.__metadata_headers = tuple(request_headers)
 
     @staticmethod
-    def __validate_additional_request_headers(additional_request_headers):
+    def __validate_additional_request_headers(additional_request_headers: Optional[Sequence[RequestHeader]]) -> None:
         if additional_request_headers is not None:
             for additional_request_header in additional_request_headers:
                 MetadataProvider.__validate_additional_request_header(additional_request_header)
 
     @staticmethod
-    def __validate_additional_request_header(additional_request_header):
+    def __validate_additional_request_header(additional_request_header: RequestHeader) -> None:
         try:
             if additional_request_header.name in MetadataProvider.__prohibited_headers:
                 raise ValueError("request header not allowed: " + str(additional_request_header))
@@ -106,11 +107,11 @@ class MetadataProvider(object):
             raise AttributeError("Each request header should have an attribute 'name' and an attribute 'value'")
 
     @IterProperty
-    def prohibited_headers(self):
+    def prohibited_headers(self) -> Sequence[str]:
         return self.__prohibited_headers
 
     @property
-    def metadata_headers(self):
+    def metadata_headers(self) -> Sequence[RequestHeader]:
         """
         :return: The server related headers containing the metadata to be
          associated with the request (if any). This will always contain at least
@@ -119,12 +120,12 @@ class MetadataProvider(object):
         return self.__metadata_headers
 
     @property
-    def _platform_identifier(self):
+    def _platform_identifier(self) -> str:
         return platform.system() + " " + platform.release() + "/" + \
                platform.version() + " Python/" + platform.python_version() + \
                " (" + platform.python_implementation() + "; " + \
                str(platform.python_compiler()) + ")"
 
     @property
-    def _sdk_identifier(self):
-        return "Python2ServerSDK/v" + self.__sdk_version
+    def _sdk_identifier(self) -> str:
+        return "Python3ServerSDK/v" + self.__sdk_version
